@@ -3,13 +3,14 @@ from callback import Callback
 
 
 @contextmanager
-def managed(sessionClass, auto_flush=False, auto_commit=False, callback=None):
+def managed(sessionClass, auto_flush=False, auto_commit=False, callback=None, commit_on_success=True):
     session = sessionClass()
     session.autoflush = auto_flush
     session.autocommit = auto_commit
     try:
         yield session
-        session.commit()
+        if commit_on_success:
+            session.commit()
     except:
         session.rollback()
         if isinstance(callback, Callback):
@@ -18,11 +19,3 @@ def managed(sessionClass, auto_flush=False, auto_commit=False, callback=None):
     finally:
         session.close()
 
-
-@contextmanager
-def commit_on_success(session):
-    try:
-        yield session
-        session.commit()
-    except:
-        raise
